package main

import (
	"cicv-data-closedloop/kinglong/common/cfg"
	"cicv-data-closedloop/kinglong/common/log"
	commonService "cicv-data-closedloop/kinglong/common/svc"
	controlConfig "cicv-data-closedloop/kinglong/control/pkg/cfg"
	"time"
)

func init() {
	// 初始化日志配置
	log.InitLogConfig()
	// 初始化本地配置文件（第1处配置，在本地文件）
	cfg.InitLocalConfig()
	// 初始化Oss连接信息
	cfg.InitOssConfig()
	// 初始化业务逻辑配置信息，配置文件在oss上（第2处配置，在oss文件）
	cfg.InitCloudConfig()
	// 首先初始化平台配置。
	cfg.InitPlatformConfig()
	// 初始化rpc客户端，用于杀死旧的采集程序
	controlConfig.InitRpcClient()
}

func main() {

	//  轮询任务接口判断是否有更新
	for {
		time.Sleep(time.Duration(1) * time.Second)
		// 1 获取当前设备的任务的 status
		status, err := cfg.GetStatus(cfg.PlatformConfig.TaskConfigId)
		if err != nil {
			log.GlobalLogger.Error("获取配置status失败：", err)
			continue
		}
		// 2 判断 status
		// UN_CHANGE 没有新的任务，无需更改
		// CHANGE 有新的任务，需要杀死旧的任务并重启
		// NONE 设备没有配置任务，需要杀死旧的任务
		if status == "UN_CHANGE" {
			continue
		} else if status == "CHANGE" || status == "NONE" {
			// 发送rpc信号杀死两个服务，并重启程序
			var masterArgs *commonService.KillSignal
			var slaveArgs *commonService.KillSignal
			if status == "CHANGE" {
				masterArgs = &commonService.KillSignal{NodeName: "master", DropUploadData: cfg.PlatformConfig.DropUploadData, Restart: true}
				slaveArgs = &commonService.KillSignal{NodeName: "slave", DropUploadData: cfg.PlatformConfig.DropUploadData, Restart: true}
			}
			if status == "NONE" {
				masterArgs = &commonService.KillSignal{NodeName: "master", DropUploadData: cfg.PlatformConfig.DropUploadData, Restart: false}
				slaveArgs = &commonService.KillSignal{NodeName: "slave", DropUploadData: cfg.PlatformConfig.DropUploadData, Restart: false}
			}
			var reply int
			err = controlConfig.KillRpcClientMaster.Call("KillService.Kill", masterArgs, &reply)
			if err != nil {
				log.GlobalLogger.Error("发送rpc请求到master失败：", err)
			}
			err = controlConfig.KillRpcClientSlave.Call("KillService.Kill", slaveArgs, &reply)
			if err != nil {
				log.GlobalLogger.Error("发送rpc请求到slave失败：", err)
			}
			// 获取一下最新配置
			cfg.InitPlatformConfig()
		} else {
			log.GlobalLogger.Error("未知的采集任务状态。status=", status)
		}
	}

}
